@@ -1,4 +1,5 @@
 """A pytest plugin useful to test tox itself (and its plugins)."""
+
 from __future__ import annotations
 
 import inspect
@@ -15,7 +16,7 @@ from types import ModuleType, TracebackType
 from typing import TYPE_CHECKING, Any, Callable, Iterator, Protocol, Sequence, cast
 
 import pytest
-from _pytest.fixtures import SubRequest
+from _pytest.fixtures import SubRequest  # noqa: PLC2701
 from devpi_process import IndexServer
 from virtualenv.info import fs_supports_symlink
 
@@ -150,7 +151,7 @@ class ToxProject:
                 value = f"from __future__ import annotations\n{value}"  # noqa: PLW2901
             if isinstance(value, dict):
                 at_path.mkdir(exist_ok=True)
-                ToxProject._setup_files(at_path, None, value)  # noqa: SLF001
+                ToxProject._setup_files(at_path, None, value)
             elif isinstance(value, str):
                 at_path.write_text(textwrap.dedent(value), encoding="utf-8")
             elif value is None:
@@ -186,14 +187,14 @@ class ToxProject:
             def wait(self, timeout: float | None = None) -> int | None:  # noqa: ARG002
                 return self._exit_code
 
-            def write_stdin(self, content: str) -> None:  # noqa: ARG002
+            def write_stdin(self, content: str) -> None:  # noqa: ARG002, PLR6301
                 return None  # pragma: no cover
 
-            def interrupt(self) -> None:
+            def interrupt(self) -> None:  # noqa: PLR6301
                 return None  # pragma: no cover
 
         class MockExecuteInstance(ExecuteInstance):
-            def __init__(  # noqa: PLR0913
+            def __init__(
                 self,
                 request: ExecuteRequest,
                 options: ExecuteOptions,
@@ -296,12 +297,12 @@ class ToxProject:
 @pytest.fixture(autouse=True, scope="session")
 def enable_pep517_backend_coverage() -> Iterator[None]:  # noqa: PT004
     try:
-        import coverage  # noqa: F401
+        import coverage  # noqa: F401, PLC0415
     except ImportError:  # pragma: no cover
         yield  # pragma: no cover
         return  # pragma: no cover
     # the COV_ env variables needs to be passed on for the PEP-517 backend
-    from tox.tox_env.python.virtual_env.package.pyproject import Pep517VirtualEnvPackager
+    from tox.tox_env.python.virtual_env.package.pyproject import Pep517VirtualEnvPackager  # noqa: PLC0415
 
     def default_pass_env(self: Pep517VirtualEnvPackager) -> list[str]:
         result = previous(self)
@@ -390,7 +391,7 @@ class ToxRunOutcome:
     @staticmethod
     def matches(pattern: str, text: str, flags: int = 0) -> None:
         try:
-            from re_assert import Matches
+            from re_assert import Matches  # noqa: PLC0415
         except ImportError:  # pragma: no cover # hard to test
             match = re.match(pattern, text, flags)
             if match is None:
@@ -406,8 +407,7 @@ class ToxProjectCreator(Protocol):
         files: dict[str, Any],
         base: Path | None = None,
         prj_path: Path | None = None,
-    ) -> ToxProject:
-        ...
+    ) -> ToxProject: ...
 
 
 @pytest.fixture(name="tox_project")
@@ -424,7 +424,7 @@ def init_fixture(
     return _init
 
 
-@pytest.fixture()
+@pytest.fixture
 def empty_project(tox_project: ToxProjectCreator, monkeypatch: pytest.MonkeyPatch) -> ToxProject:
     project = tox_project({"tox.ini": ""})
     monkeypatch.chdir(project.path)
@@ -443,7 +443,7 @@ def pytest_configure(config: pytest.Config) -> None:
     config.addinivalue_line("markers", "plugin_test")
 
 
-@pytest.hookimpl(trylast=True)  # type: ignore[misc] # not typed decorator
+@pytest.hookimpl(trylast=True)
 def pytest_collection_modifyitems(config: pytest.Config, items: list[pytest.Function]) -> None:
     # do not require flags if called directly
     if len(items) == 1:  # pragma: no cover # hard to test
@@ -527,12 +527,12 @@ MonkeyPatch = pytest.MonkeyPatch
 __all__ = (
     "CaptureFixture",
     "LogCaptureFixture",
-    "TempPathFactory",
     "MonkeyPatch",
     "SubRequest",
-    "ToxRunOutcome",
+    "TempPathFactory",
     "ToxProject",
     "ToxProjectCreator",
+    "ToxRunOutcome",
     "check_os_environ",
     "register_inline_plugin",
 )
